@@ -9,7 +9,7 @@
 
 #include "knumber.h"
 #include <QFrame>
-#include <QVector>
+#include <QList>
 
 class CalcEngine;
 class QTimer;
@@ -96,11 +96,7 @@ protected:
 private:
     bool changeSign();
     void invertColors();
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    void initStyleOption(QStyleOptionFrame *option) const override; // virtual in Qt6
-#else
-    void initStyleOption(QStyleOptionFrame *option) const;
-#endif
+    void initStyleOption(QStyleOptionFrame *option) const override;
     void updateFont();
 
 private Q_SLOTS:
@@ -128,7 +124,7 @@ private:
 
     QFont baseFont_;
 
-    QVector<KNumber> history_list_;
+    QList<KNumber> history_list_;
     int history_index_;
 
     // only used for input of new numbers
